
###############################################################################################
#  AN EXAMPLE TO FIT THE GRADED RESPONSE MODEL:   Bayesian Inference                          #                                       
#                                                                                             #
# Data contain answers of 333 respondent to 4 items of the scale of attitudes toward Mobile   #
# mobil banking of Puschel, Mazzon e Hernandez (2010).                                        #
# Data are described in Bazn J., Merino, M. H. and Mazzon, J. A. (2011).                     #
# Classificao de modelos de resposta ao item policotmicos com aplicao ao marketing.      #
# Revista Brasileira de Estatstica, 72, 7-39.                                                #
#                                                                                             #
###############################################################################################



# install package foreign
#install.packages("foreign") 


#read data

require(foreign)  
wd="C:/Users/Jorge Luis/Copy/MinicursTRI/Exemplos/Graded"
setwd(wd)

attitude<- read.spss(file="No usuarios - Atitude2.sav", use.value.labels=TRUE, max.value.labels=Inf,to.data.frame = TRUE)



y=as.matrix(attitude)
colnames(y) <- NULL 

n=nrow(attitude)
I=ncol(attitude)
m=6
data<-list(y=y,n=n,I=I,m=m)

inits<-function(){list(a=c(rep(1,I)), b.star=matrix(rep(0.5,I*(m-1)),I,m-1), theta=c(rep(0.5,n)))}

parameters<-c("a","b","bc","theta")

n.iter=1400  #Consider 24000
n.burnin=400 #Consider 4000
n.thin=1     #Consider 20

#Usando WinBUGS
##############
#To install WinBUGS see http://www.wcsmalaysia.org/analysis/WinBUGS_install.htm


library(R2WinBUGS)
#bugs directory home
bd="C:/Program Files/WinBUGS14/"

bayesgrmw<-bugs(data,inits=inits,parameters.to.save=parameters,
model.file="GRM.txt",working.directory=wd,
n.chains=1,n.iter=n.iter,n.burnin=n.burnin,n.thin=n.thin,bugs.directory=bd)

plot(bayesgrmw)

print(bayesgrmw,digits=2)


#convergence analysis

bayesgrmw2<-bugs(data,inits=inits,parameters.to.save=parameters,
model.file="GRM.txt",working.directory=wd,codaPkg = TRUE,
n.chains=1,n.iter=n.iter,n.burnin=n.burnin,n.thin=n.thin,bugs.directory=bd)

library("coda")
codaobject <- read.bugs(bayesgrmw2)
summary(codaobject)
effectiveSize(codaobject)

#parameter a
geweke.diag(codaobject[,c(1:4)])
plot(codaobject[,c(1:4)])
densityplot(codaobject[,c(1:4)]) 
xyplot(codaobject[,c(1:4)])
acfplot(codaobject[,c(1:4)])

#parameter b
geweke.diag(codaobject[,c(5:24)])
plot(codaobject[,c(5:24)])
densityplot(codaobject[,c(5:24)]) 
xyplot(codaobject[,c(5:24)])
acfplot(codaobject[,c(5:24)])

#parameter bc
geweke.diag(codaobject[,c(25:44)])
plot(codaobject[,c(25:44)])
densityplot(codaobject[,c(25:44)]) 
xyplot(codaobject[,c(25:44)])
acfplot(codaobject[,c(25:44)]) 

#Note. WinBugs and R2WinBUGS is more quickly that OpenBUGS with R2OpenBUGS or brugs

