
###############################################################################################
#  AN EXAMPLE TO FIT THE GRADED RESPONSE MODEL:   Bayesian Inference                          #                                       
#                                                                                             #
# Data contain answers of 333 respondent to 4 items of the scale of attitudes toward Mobile   #
# mobil banking of Puschel, Mazzon e Hernandez (2010).                                        #
# Data are described in Bazn J., Merino, M. H. and Mazzon, J. A. (2011).                     #
# Classificao de modelos de resposta ao item policotmicos com aplicao ao marketing.      #
# Revista Brasileira de Estatstica, 72, 7-39.                                                #
#                                                                                             #
###############################################################################################



# install package ltm, psych, foreign
#install.packages(c("ltm","psych","foreign") 

#read data

require(foreign)  
wd="C:\\Users\\Jorge Luis\\Copy\\MinicursTRI\\Exemplos\\Graded"
setwd(wd)

attitude<- read.spss(file="No usuarios - Atitude2.sav", use.value.labels=TRUE, 
max.value.labels=Inf,to.data.frame = TRUE)


#Classical item analysis 
require(ltm)
cronbach.alpha(attitude)

require(psych)
alpha(attitude)


# Evaluation of multidimensionality

fa(attitude)  #factor analysis using pearson correlation matrix

require(psych)
c=polychoric(attitude)

fap <- fa(r=c$rho)  #factor analysis using polychoric correlation matrix
fap

par(mfrow=c(1,2))
fa.diagram(fap,cut=0.4)
factor.plot(fap,cut=0.4,ylim=c(0,1),xlim=c(0,5))
abline(h=0.4,col=4,lty=2)


#ML Estimation of Graded response model using ltm: Calibration of items
#with usual parameterization

require(ltm)
fitGRM=grm(attitude)

fitGRM
summary(fitGRM)


#help(grm)

#Area under the Test or Item Information Curves, can be considered some items
information(fitGRM,  c(-4,  4))

#ploteos
opar=par(mfrow = c(2, 2))
plot(fitGRM, lwd = 2, legend = TRUE, ncol = 2)


## Item Information Curves for the Atitude data;
plot(fitGRM, type = "IIC", legend = TRUE, cx = "topright", lwd = 2, cex = 1.4)


#ML estimation of abilities with item parameters knowns
require(ltm)

detach("package:psych", unload=TRUE)

fscEAP=factor.scores(fitGRM,method="EAP")
fscEAP

 
trait<-fscEAP$score.dat$z1
par(mfrow=c(1,1))
hist(trait,xlim=c(-3,3))

# Note. Reviewed your results with carefully  Compare your results with the obtained 
# using other software. For example you can use IRTPRO
# http://www.ssicentral.com/irt/student.html

